@@ -3,7 +3,8 @@ from django.contrib import admin
 from django.contrib.contenttypes import generic
 from reversion.admin import VersionAdmin
 
-from armstrong.hatband.options import GenericKeyInline
+from armstrong.hatband.options import BackboneInline
+from armstrong.hatband.forms import OrderableGenericKeyLookupForm
 
 from . import models
 
@@ -12,9 +13,20 @@ class NodeAdmin(VersionAdmin):
     pass
 
 
-class NodeInline(GenericKeyInline):
+class NodeInlineAdminForm(OrderableGenericKeyLookupForm):
+    class Media:
+        js = (
+                'hatband/js/jquery-ui-1.8.16.min.js',
+                'arm_wells/js/well-node-inline.js',
+              )
+        css = {'all': ('arm_wells/css/well-node-inline.css',
+                       'hatband/css/jquery/ui-lightness/jquery-ui-1.8.16.custom.css',)}
+
+
+class NodeInline(BackboneInline):
+    template = 'arm_wells/admin/well-node-inline.html'
+    form = NodeInlineAdminForm
     model = models.Node
-    extra = 1
 
     # This is for Grappelli
     sortable_field_name = "order"
